@@ -1,17 +1,18 @@
 """
 A collection of useful string utilities.
 """
+from typing import Optional
 
 # Strings representing boolean values
-TRUE_STRINGS = ['true', '1', 'yes', 'on']
-FALSE_STRINGS = ['false', '0', 'no', 'off']
+TRUE_STRINGS = ('y', 'yes', 't', 'true', 'on', '1')
+FALSE_STRINGS = ('n', 'no', 'f', 'false', 'off', '0')
 BOOL_STRINGS = TRUE_STRINGS + FALSE_STRINGS
 
 # default value of that's considered 'SHORT'
 SHORT_STRING_LEN = 64
 
 
-def trim(value, default_value=''):
+def trim(value, default_value='') -> Optional[str]:
     """
     Removes leading and trailing whitespace from the specified string. If the specified string is an empty
     string, ``None`` or a string composed of whitespace only, the specified default value is returned.
@@ -95,7 +96,7 @@ def string_2_bool(value) -> bool:
     :raises: ValueError if the string is not one of the known values.
     :rtype: bool
     """
-    value = trim(value).lower()
+    value = trim_to_lower(value)
     if value in TRUE_STRINGS:
         return True
     elif value in FALSE_STRINGS:
